#!/usr/bin/python
"""Reads an fiwalk XML file and reports how many of the files are still in the image..."""

import hashlib
import os.path
import fiwalk

present = []
not_present = []

def process_file(fi):
    print "process file",fi.filename()
    if fi.filesize()==0: return
    for hashname in ['md5','sha1']:
        if hashname in fi.tags:
            oldhash = fi.tags[hashname]
            newhash = hashlib.new(hashname,fi.contents()).hexdigest()
            if oldhash==newhash:
                present.append(fi)
            else:
                fi.reason = "%s hash changed from '%s' to '%s'" % (hashname,oldhash,newhash)
                not_present.append(fi)
            return
    raise RuntimeError,"Cannot process file "+fi.filename()+" as there is no matching hash in "+str(fi)



################################################################
if __name__=="__main__":
    import sys
    from optparse import OptionParser
    from subprocess import Popen,PIPE
    global options

    parser = OptionParser()
    parser.add_option("-d","--debug",help="prints debugging info",dest="debug")
    parser.add_option("-g","--ground",help="ground truth XML file",dest="ground")
    parser.usage = '%prog [options] image.iso'
    (options,args) = parser.parse_args()

    if not options.ground:
        parser.print_help()
        sys.exit(1)

    # Read the redaction configuration file
    imagefilename = args[0]
    reader = fiwalk.fiwalk_xml_reader()
    reader.set_imagefilename(imagefilename)
    reader.process_xml_stream(open(options.ground,"r"),process_file)

    if len(present)==0:
        print "None of the files are present in the image"
        sys.exit(0)

    if len(not_present)==0:
        print "All of the files are present in the image"
        sys.exit(0)

    print "\n\n"
    print "Present in image:"
    print "================="
    print "\n".join([fi.filename() for fi in present])

    print "\n"
    print "Not Present or altered in image:"
    print "====================="
    for fi in not_present:
        print fi.filename(),"\t",fi.reason

    

